<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="214"/>
        <source>Drop Error</source>
        <translation>Errorea jaregitean</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="215"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>&apos;%1&apos; fitxategia/URLa ezin da QuickLaunch-en txertatu oraingoz</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="321"/>
        <source>Drop application
icons here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>Move left</source>
        <translation>Mugitu ezkerrera</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="58"/>
        <source>Move right</source>
        <translation>Mugitu eskuinera</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="62"/>
        <source>Remove from quicklaunch</source>
        <translation>Kendu abio azkarretik</translation>
    </message>
</context>
</TS>
